@@ -14,17 +14,18 @@
 
 # pylint: disable=C0330, g-bad-import-order, g-multiple-import
 
-"""Simplifies imports from inner modules."""
+"""Library for AI creative analysis.
+
+Generates creative maps to be viewed via `https://filonov-ai.web.app/`.
+"""
 
 from filonov.creative_map import CreativeMap
 from filonov.filonov_service import CreativeMapGenerateRequest, FilonovService
-from filonov.inputs.input_service import MediaInputService
 
 __all__ = [
   'FilonovService',
   'CreativeMapGenerateRequest',
-  'MediaInputService',
   'CreativeMap',
 ]
 
-__version__ = '0.3.0'
+__version__ = '0.7.0'
